ALLOWED_MODULES = [
    'abc',
    'array',
    'base64',
    'bisect',
    'binascii',
    'calendar',
    'cmath',
    'codecs',
    'collections',
    'copy',
    'datetime',
    'decimal',
    'fractions',
    'functools',
    'hashlib',
    'heapq',
    'itertools',
    'math',
    'numbers',
    'operator',
    'pprint',
    'random',
    're',
    'replib',
    'statistics',
    'string',
    'stringprep',
    'struct',
    'textwrap',
    'time',
    'types',
    'unicodedata',
    'unittest',
    'weakref',
    '_strptime',
]

CLOSE_BUILDINS = [
    'memoryview',
    'open',
    'buffer',
    'execfile',
    'raw_input',
    'input',
    'reload',
    'help'
]
